@@ -21,6 +21,14 @@ class http_server:
         self.update_elapse = 0.1
         self.running = True
         self.routes = web.RouteTableDef()
+        self.route_get = self.routes.get
+        self.route_post = self.routes.post
+        self.route_head = self.routes.head
+        self.route_patch = self.routes.patch
+        self.route_put = self.routes.put
+        self.route_static = self.routes.static
+        self.route_view = self.routes.view
+        self.route = self.routes.route
 
     def add_route(self, method, path, handler):
         self.app.router.add_route(method, path, handler)
@@ -29,6 +37,7 @@ class http_server:
         self.app.router.add_routes(routes)
 
     async def common_run(self):
+        self.add_routes(self.routes)
         runner = web.AppRunner(self.app)
         await runner.setup()
         site = web.TCPSite(runner, host=self.host, port=self.port)
@@ -57,6 +66,7 @@ class http_server:
         await site.stop()
 
     def run(self):
+        self.add_routes(self.routes)
         web.run_app(self.app, host=self.host, port=self.port)
 
     def add_update_func(self, f):
